@@ -1,6 +1,6 @@
 package Datahub::Factory;
 
-our $VERSION = '0.7';
+our $VERSION = '0.8';
 
 use Datahub::Factory::Sane;
 
@@ -12,15 +12,32 @@ use Sub::Exporter -setup => {
     exports => [
         log              => curry_method,
         cfg              => curry_method,
+        importer         => curry_method,
+        fixer            => curry_method,
+        store            => curry_method,
+        exporter         => curry_method,
     ],
     collectors => {'-load' => \'_import_load', ':load' => \'_import_load',},
 };
 
 sub _import_load {
-  my $class = shift;
-  my $env   = Datahub::Factory::Env->new();
-  $class->_env($env);
-  $class;
+    my ($self, $value, $data) = @_;
+
+    if (is_array_ref $value) {
+      self->load(@$value);
+    }
+    else {
+      $self->load;
+    }
+
+    1;
+}
+
+sub load {
+    my $class = shift;
+    my $env   = Datahub::Factory::Env->new();
+    $class->_env($env);
+    $class;
 }
 
 sub _env {
@@ -31,6 +48,26 @@ sub _env {
         ||= Datahub::Factory::Env->new();
 }
 
+sub store {
+    my $class = shift;
+    $class->_env->store(@_);
+}
+
+sub importer {
+    my $class = shift;
+    $class->_env->importer(@_);
+}
+
+sub fixer {
+    my $class = shift;
+    $class->_env->fixer(@_);
+}
+
+sub exporter {
+    my $class = shift;
+    $class->_env->exporter(@_);
+}
+
 sub log {
 	$_[0]->_env->log;
 }
@@ -48,7 +85,7 @@ __END__
 
 =head1 NAME
 
-[![Build Status](https://travis-ci.org/thedatahub/Datahub-Factory.svg?branch=master)](https://travis-ci.org/thedatahub/Datahub-Factory)
+=for html <a href="https://travis-ci.org/thedatahub/Datahub-Factory"><img src="https://travis-ci.org/thedatahub/Datahub-Factory.svg?branch=master"></a>
 
 Datahub::Factory - A conveyor belt which transports data from a data source to
 a data sink.
@@ -138,13 +175,6 @@ export the data.
 
 L<Datahub::Factory::Command::transport>
 
-=head2 merge [OPTIONS] (experimental)
-
-Fetch data from two sources, convert it to an exchange format, merge the
-two records and export the data.
-
-L<Datahub::Factory::Command::merge>
-
 =head1 AUTHORS
 
 =over
