@@ -19,13 +19,7 @@ sub description { "Long description on blortex algorithm" }
 
 sub opt_spec {
 	return (
-		[ "pipeline|i:s", "Location of the pipeline configuration file"],
-		[ "importer|i:s",  "The importer" ],
-		[ "datahub|d:s",  "The datahub instance" ],
-		[ "exporter|e:s",  "The exporter"],
-		[ "fixes|f:s",  "Fixes"],
-		[ "oimport|oi:s%",  "import options"],
-		[ "oexport|oe:s%",  "export options"],
+		[ "pipeline|p:s", "Location of the pipeline configuration file"]
 	);
 }
 
@@ -36,7 +30,7 @@ sub validate_args {
 	if (defined($pc->check_object())) {
 		$self->usage_error($pc->check_object())
 	}
-	
+
 
 	# no args allowed but options!
 	$self->usage_error("No args allowed") if @$args;
@@ -53,37 +47,18 @@ sub execute {
   my $cfg = Datahub::Factory->cfg;
 
   # Load modules
-  my $export_module = sprintf("Datahub::Factory::Exporter::%s", $opt->{exporter});;
-  autoload $export_module;
-
-  my $fix_module = 'Datahub::Factory::Fixer';
-  autoload $fix_module;
-
-  my $import_module = sprintf("Datahub::Factory::Importer::%s", $opt->{importer});
-  autoload $import_module;
+  my $import_module = Datahub::Factory->importer($opt->{importer}, $opt->{oimport});
+  my $fix_module = Datahub::Factory->fixer($opt->{fixer}, {"file_name" => $opt->{fixes}});
+  my $export_module = Datahub::Factory->exporter($opt->{exporter}, $opt->{oexport});
 
+  # Do we still need next two code blocks?
   # Perform import/fix/export
-  my $catmandu_input;
-  if (! defined($opt->{oimport}) || ! %{$opt->{oimport}}) {
-	  $catmandu_input = $import_module->new();
-  } else {
-	  $catmandu_input = $import_module->new($opt->{oimport});
-  }
 
-  my $catmandu_fixer = $fix_module->new("file_name" => $opt->{fixes});
-
-  my $catmandu_output;
-  if (! defined($opt->{oexport}) || ! %{$opt->{oexport}}) {
-	  $catmandu_output = $export_module->new();
-  } else {
-	  $catmandu_output = $export_module->new($opt->{oexport});
-  }
-
-  $catmandu_fixer->fixer->fix($catmandu_input->importer)->each(sub {
+  $fix_module->fixer->fix($import_module->importer)->each(sub {
     my $item = shift;
     my $item_id = data_at($opt->{'id_path'}, $item);
     try {
-    	$catmandu_output->out->add($item);
+    	$export_module->out->add($item);
     } catch {
         my $msg;
         if ($_->can('message')) {
@@ -267,7 +242,7 @@ C<file_name> points to the location of your Fix file.
   id_path = ''
 
   [plugin_exporter_Datahub]
-  datahub_url = my.thedatahub.io
+  datahub_url = https://my.thedatahub.io
   datahub_format = LIDO
   oauth_client_id = datahub
   oauth_client_secret = datahub
